pitchtools.expr_has_duplicate_named_chromatic_pitch
===================================================

.. autofunction:: abjad.tools.pitchtools.expr_has_duplicate_named_chromatic_pitch.expr_has_duplicate_named_chromatic_pitch
